@@ -14,25 +14,29 @@ use Config;
 require Exporter;
 @ISA = qw(Exporter);
 
-$VERSION = "1.01";
+$VERSION = "1.02";
 
 @EXPORT_OK = qw(
-	IPC_ALLOC IPC_CREAT IPC_EXCL IPC_LOCKED IPC_M
-	IPC_NOERROR IPC_NOWAIT IPC_PRIVATE IPC_R IPC_RMID
-	IPC_SET IPC_STAT IPC_W IPC_WANTED
+	GETALL GETNCNT GETPID GETVAL GETZCNT
+
+	IPC_ALLOC IPC_CREAT IPC_EXCL IPC_GETACL IPC_LOCKED IPC_M
+	IPC_NOERROR IPC_NOWAIT IPC_PRIVATE IPC_R IPC_RMID IPC_SET
+	IPC_SETACL IPC_SETLABEL IPC_STAT IPC_W IPC_WANTED
 
 	MSG_FWAIT MSG_LOCKED MSG_MWAIT MSG_NOERROR MSG_QWAIT
 	MSG_R MSG_RWAIT MSG_STAT MSG_W MSG_WWAIT
 
-	SEM_A SEM_ALLOC SEM_DEST SEM_ERR SEM_R SEM_ORDER SEM_UNDO
-	GETVAL GETPID GETNCNT GETZCNT GETALL SETVAL SETALL
+	SEM_A SEM_ALLOC SEM_DEST SEM_ERR SEM_ORDER SEM_R SEM_UNDO
+
+	SETALL SETVAL
 
-	SHM_A SHM_CLEAR SHM_COPY SHM_DEST SHM_FMAP SHM_INIT
-	SHM_LOCK SHM_LOCKED SHM_MAP SHM_NOSWAP SHM_R SHM_RDONLY
-	SHM_REMOVED SHM_RND SHM_SHARE_MMU SHM_SHATTR SHM_SIZE
-	SHM_UNLOCK SHM_W
 	SHMLBA
 
+	SHM_A SHM_CLEAR SHM_COPY SHM_DCACHE SHM_DEST SHM_ECACHE
+	SHM_FMAP SHM_ICACHE SHM_INIT SHM_LOCK SHM_LOCKED SHM_MAP
+	SHM_NOSWAP SHM_R SHM_RDONLY SHM_REMOVED SHM_RND SHM_SHARE_MMU
+	SHM_SHATTR SHM_SIZE SHM_UNLOCK SHM_W
+
 	S_IRUSR S_IWUSR S_IRWXU
 	S_IRGRP S_IWGRP S_IRWXG
 	S_IROTH S_IWOTH S_IRWXO
@@ -70,9 +74,14 @@ C<IPC::SysV> defines and conditionally exports all the constants
 defined in your system include files which are needed by the SysV
 IPC calls.
 
+=item ftok( PATH, ID )
+
+Return a key based on PATH and ID, which can be used as a key for
+C<msgget>, C<semget> and C<shmget>. See L<ftok>
+
 =head1 SEE ALSO
 
-L<IPC::Msg> L<IPC::Semaphore>
+L<IPC::Msg>, L<IPC::Semaphore>, L<ftok>
 
 =head1 AUTHORS
 
